@@ -79,3 +79,36 @@ test_that("outputs as many rows per `dataset` as columns in `dataset`", {
   out2 <- transform(out, is_equal = out$n == out$n_col)
   expect_true(all(out2$is_equal))
 })
+
+test_that("Some datasets use tonne or tonnes, but not ton nor tons", {
+  library(r2dii.data)
+  datasets <- r2dii.data:::enlist_datasets("r2dii.data")
+
+  # Helpers
+  length_columns_contain <- function(data, pattern) {
+    out <- lapply(data, column_contains, pattern = pattern)
+    length(discard_empty(out))
+  }
+  column_contains <- function(data, pattern) {
+    out <- lapply(data, function(.x) any(grepl(pattern = pattern, .x)))
+    names(keep_true(out))
+  }
+  discard_empty <- function(x) {
+    empty <- unlist(lapply(x, function(x) length(x) == 0))
+    x[is.na(x) | !empty]
+  }
+  keep_true <- function(x) {
+    true <- unlist(x)
+    x[!is.na(x) & true]
+  }
+
+  # Some datasets have values that contain " tonnes "
+  expect_true(length_columns_contain(datasets, pattern = " tonne ") > 0)
+  # Some datasets have values that start with "tonnes "
+  expect_true(length_columns_contain(datasets, pattern = "^tonnes ") > 0)
+
+  # No dataset has values that contain " ton "
+  expect_false(length_columns_contain(datasets, pattern = " ton ") > 0)
+  # No dataset has values that start with "ton "
+  expect_false(length_columns_contain(datasets, pattern = "^ton ") > 0)
+})
